@@ -68,7 +68,7 @@ class MultiCurrencyPrice(models.Model):
 
     def save(self, **kwargs):
 
-        rates = ExchangeRates.objects.get()
+        rates = ExchangeRates.get_solo()
 
         field = lambda c: 'price_{}'.format(CURRENCY_NAMES[c])
 
