@@ -1,5 +1,5 @@
 
-from django.urls import path
+from django.urls import path, include
 
 from exchange import views
 
@@ -12,3 +12,9 @@ urlpatterns = [
     path('set-currency/', views.set_currency, name='set-currency')
 
 ]
+
+
+app_urls = [
+    path('exchange/', include((urlpatterns, app_name)))
+]
+
